#
# spec file for package ConsoleKit
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           ConsoleKit
%define         build_doc 0
%define         pkg_name ConsoleKit
%define         _udevdir %(pkg-config --variable=udevdir udev)
# WARNING: If you are editing ConsoleKit-doc.spec, STOP. Always edit
# ConsoleKit.spec and then run pre-checkin.sh which will create
# ConsoleKit-doc.spec based upon ConsoleKit.spec.
Url:            http://www.freedesktop.org/wiki/Software/ConsoleKit/
BuildRequires:  dbus-1-glib-devel
BuildRequires:  glib2-devel
BuildRequires:  glibc-devel
BuildRequires:  libacl-devel
BuildRequires:  libtool
BuildRequires:  pam-devel
BuildRequires:  pkgconfig
BuildRequires:  polkit-devel
BuildRequires:  xorg-x11-libX11-devel
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(udev)
%if %build_doc
BuildRequires:  gtk2-devel
BuildRequires:  xmlto
Provides:       ConsoleKit:/usr/share/doc/packages/ConsoleKit/spec/ConcoleKit.html
%endif
Summary:        System daemon for tracking users, sessions and seats
License:        GPL-2.0+
Group:          System/Daemons
Version:        0.4.6
Release:        9.3
Source:         http://www.freedesktop.org/software/%{pkg_name}/dist/%{pkg_name}-%{version}.tar.xz
Source2:        baselibs.conf
Patch0:         move-pid-and-database-to-run-directory.patch
Obsoletes:      udev-acl <= 173
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%{?systemd_requires}
%if %build_doc == 0
PreReq:         pwdutils login
PreReq:         pam-config >= 0.22
%endif

%description
ConsoleKit is a system daemon for tracking what users are logged into
the system and how they interact with the computer (e.g. which keyboard
and mouse they use).

%if !%{build_doc}

%package -n ConsoleKit-devel
Summary:        Developer package for ConsoleKit
Group:          Development/Libraries/Other
Requires:       %{pkg_name} = %{version}-%{release}
Requires:       dbus-1-devel

%description -n ConsoleKit-devel
Developer package for ConsoleKit and libck-connector

%package -n ConsoleKit-x11
Summary:        System daemon for tracking users, sessions and seats
Group:          System/Daemons
Requires:       %{pkg_name} = %{version}-%{release}
Supplements:    packageand(xorg-x11:ConsoleKit)

%description -n ConsoleKit-x11
ConsoleKit is a system daemon for tracking what users are logged into
the system and how they interact with the computer (e.g. which keyboard
and mouse they use).

%endif

%prep
%setup -q -n ConsoleKit-%{version}
%patch0 -p1

%build
export V=1
autoreconf -fi
./configure CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing" \
  --prefix=/usr \
  --libdir=%_libdir \
  --mandir=%_mandir \
  --sysconfdir=%_sysconfdir \
  --libexecdir=%{_prefix}/lib/ConsoleKit \
  --enable-pam-module \
  --enable-udev-acl \
  --with-pam-module-dir=/%_lib/security \
  --with-pid-file=/run/ConsoleKit/pid \
  --localstatedir=%{_localstatedir} \
%if %{build_doc}
  --enable-docbook-docs \
%endif
  --docdir=%{_datadir}/doc/packages/ConsoleKit
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} UDEVDIR=%{_udevdir} install
mkdir -p $RPM_BUILD_ROOT/etc/init.d
mkdir -p $RPM_BUILD_ROOT/etc/ConsoleKit/seats.d
mkdir -p $RPM_BUILD_ROOT%{_udevdir}/rules.d
rm -f $RPM_BUILD_ROOT/%_lib/security/pam_ck_connector.la
rm -f $RPM_BUILD_ROOT/%_libdir/*.la
%if %{build_doc}
rm -rf $RPM_BUILD_ROOT/%_libdir/*.so*
rm -rf $RPM_BUILD_ROOT/%{_datadir}/dbus-1/system-services/org.freedesktop.ConsoleKit.service
rm -rf $RPM_BUILD_ROOT/%_sysconfdir/dbus-1/system.d/ConsoleKit.conf
rm -rf $RPM_BUILD_ROOT/%_sysconfdir/ConsoleKit/seats.d/00-primary.seat
rm -rf $RPM_BUILD_ROOT/%_sysconfdir/init.d/consolekit
rm -rf $RPM_BUILD_ROOT/%_bindir/
rm -rf $RPM_BUILD_ROOT/%_includedir/ConsoleKit
rm -rf $RPM_BUILD_ROOT/%_libdir/
rm -rf $RPM_BUILD_ROOT/%_sbindir/
rm -rf $RPM_BUILD_ROOT/%_mandir/
rm -rf $RPM_BUILD_ROOT/%{_prefix}/lib
rm -rf $RPM_BUILD_ROOT/%_lib/security
rm -rf $RPM_BUILD_ROOT/%_datadir/polkit-1/actions/org.freedesktop.consolekit.policy
rm -rf $RPM_BUILD_ROOT/%_datadir/dbus-1/interfaces/org.freedesktop.ConsoleKit.Manager.xml
rm -rf $RPM_BUILD_ROOT/%_datadir/dbus-1/interfaces/org.freedesktop.ConsoleKit.Seat.xml
rm -rf $RPM_BUILD_ROOT/%_datadir/dbus-1/interfaces/org.freedesktop.ConsoleKit.Session.xml
rm -rf $RPM_BUILD_ROOT/lib/systemd/
%endif
%if !%{build_doc}

%pre
%service_add_pre console-kit-daemon.service

%post
/sbin/ldconfig
%service_add_post console-kit-daemon.service
if [ -n "$YAST_IS_RUNNING" ]; then
	/usr/sbin/pam-config --service login -a -f --ck_connector
else
	/usr/sbin/pam-config --service login -a --ck_connector || echo "please call \"/usr/sbin/pam-config --service login -a --ck_connector\" manually"
fi

%preun
%service_del_preun console-kit-daemon.service

%postun
%service_del_postun console-kit-daemon.service
# make sure this is not called on update
if [ "$1" = 0 ]; then
    /usr/sbin/pam-config --service login -d --ck_connector ||:
fi
/sbin/ldconfig
%endif

%files
%defattr(-,root,root)
%if %{build_doc}
%{_datadir}/doc/packages/ConsoleKit
%else
%dir %{_sysconfdir}/ConsoleKit
%dir %{_sysconfdir}/ConsoleKit/seats.d
%dir %{_sysconfdir}/ConsoleKit/run-seat.d
%dir %{_sysconfdir}/ConsoleKit/run-session.d
%dir %{_prefix}/lib/ConsoleKit
%dir %{_prefix}/lib/ConsoleKit/run-seat.d
%dir %{_prefix}/lib/ConsoleKit/run-session.d
%dir %{_prefix}/lib/ConsoleKit/scripts
%dir %{_udevdir}
%dir %{_udevdir}/rules.d
%dir %{_localstatedir}/log/ConsoleKit
%{_udevdir}/udev-acl
%{_udevdir}/rules.d/70-udev-acl.rules
%{_prefix}/lib/ConsoleKit/run-seat.d/udev-acl.ck
%{_prefix}/lib/ConsoleKit/scripts/ck-system-restart
%{_prefix}/lib/ConsoleKit/scripts/ck-system-stop
%{_prefix}/lib/ConsoleKit/ck-collect-session-info
%{_datadir}/dbus-1/system-services/org.freedesktop.ConsoleKit.service
%config %{_sysconfdir}/dbus-1/system.d/ConsoleKit.conf
%config %{_sysconfdir}/ConsoleKit/seats.d/00-primary.seat
%{_bindir}/*
%{_libdir}/*.so.*
%{_sbindir}/*
%{_mandir}/man8/pam_ck_connector.8.gz
/%{_lib}/security
%ghost /run/ConsoleKit
%{_datadir}/polkit-1/actions/org.freedesktop.consolekit.policy
%{_datadir}/dbus-1/interfaces/org.freedesktop.ConsoleKit.Manager.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.ConsoleKit.Seat.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.ConsoleKit.Session.xml
%{_unitdir}/console-kit-daemon.service
%{_unitdir}/console-kit-log-system-restart.service
%{_unitdir}/console-kit-log-system-start.service
%{_unitdir}/console-kit-log-system-stop.service
%{_unitdir}/basic.target.wants/console-kit-log-system-start.service
%{_unitdir}/halt.target.wants/console-kit-log-system-stop.service
%{_unitdir}/kexec.target.wants/console-kit-log-system-restart.service
%{_unitdir}/poweroff.target.wants/console-kit-log-system-stop.service
%{_unitdir}/reboot.target.wants/console-kit-log-system-restart.service

%files -n ConsoleKit-devel
%defattr(-,root,root)
%{_includedir}/ConsoleKit
%{_libdir}/*.so
%{_libdir}/pkgconfig/ck-connector.pc

%files -n ConsoleKit-x11
%defattr(-,root,root)
%{_prefix}/lib/ConsoleKit/ck-get-x11-server-pid
%{_prefix}/lib/ConsoleKit/ck-get-x11-display-device
%endif

%changelog
* Thu May 22 2014 werner@suse.de
- Require the udev library for build to allow the move
  of udev.pc back to udev
* Tue Apr 15 2014 aj@suse.com
- ConsoleKit was moved to /run, fix filelist for this as well.
* Thu Jan 16 2014 aj@ajaissle.de
- New upstream release 0.4.6
  + build-sys: Use xz compression
  + build-sys: install run-seat.d symlink for udev-acl
  + build-sys: missing AC_SUBST for UDEVDIR
  + Fix unconditional PATH_MAX usage
  + Add support for GNU/Hurd
  + build-sys: don't install systemd units when using --without-systemdsystemunitdir
  + build-sys: run autoupdate
  + build-sys: remove useless dbus version check
  + Import udev-acl tool from udev
  + ck-history: don't truncate --frequent output to 8 chars
- Dropped import-udev-acl-tool-from-udev.patch (applied upstream)
- Changed Url as the former was non existent
  + former:  http://consolekit.freedesktop.org
  + current: http://www.freedesktop.org/wiki/Software/ConsoleKit/
- Rebased move-pid-and-database-to-run-directory.patch, but use configure option instead of patching the pid location
* Thu Oct 17 2013 pwieczorkiewicz@suse.com
- create %%{_localstatedir}/log/ConsoleKit directory on install
  (bnc#845872)
* Thu Jan 24 2013 rmilasan@suse.com
- move-pid-and-database-to-run-directory.patch: move database and
  pid file to /run/ConsoleKit.
* Mon Dec  3 2012 tiwai@suse.de
- obsoletes udev-acl package (bnc#791320)
* Tue Nov 27 2012 rmilasan@suse.com
- import-udev-acl-tool-from-udev.patch: add udev-acl to ConsoleKit
  for systems which don't use systemd-logind (bnc#791320).
* Thu Oct 18 2012 coolo@suse.com
- buildrequire systemd by pkgconfig provide to get systemd-mini
  in build environments (to break cycle)
* Mon Feb 27 2012 vuntz@opensuse.org
- Fix systemd-related packaging:
  + Add systemd-devel BuildRequires.
  + Use %%{?systemd_requires}.
  + Stop passing --with-systemdsystemunitdir to configure: we'll
    just use the right default value, which should be %%{_unitdir}.
  + Call %%service_{add,del}_* macros in scriptlets for
    console-kit-daemon.service.
  + Note that we don't call those macros for
    console-kit-log-system-{restart,start,stop}.service since those
    services are used in specific cases only.
* Tue Oct 11 2011 lnussel@suse.de
- move ck-collect-session-info to main package as it doesn't depend on X and is
  actually needed for ConsoleKit operation (bnc#727037)
- make ConsoleKit-x11 install if both xorg-x11 and ConsoleKit are installed
* Fri Sep 30 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from spec
* Fri Sep 16 2011 coolo@suse.com
- remove outdated _service file
* Fri Jun 17 2011 vuntz@opensuse.org
- Update to version 0.4.5:
  + Retry opening console device on EIO (fdo#31790)
  + systemd: don't pull in sysinit.target
* Wed Mar  9 2011 coolo@novell.com
- version 0.4.4
  - Small fixes for systemd support
* Wed Nov 17 2010 kay.sievers@novell.com
- version 0.4.3
  - Revert "linux: Use VT_WAITEVENT if available to avoid spawn
    too many threads"
  - Revert "linux: Check for VT_WAITEVENT ioctl during runtime"
  - systemd: simplify unit files a little
  - systemd: log shutdown when doing kexec reboot
  - dbus: bump dependency on dbus-glib to 0.82
  - linux: Check for VT_WAITEVENT ioctl during runtime
  - build-sys: Bump GLIB_REQUIRED_VERSION to 2.14 for GRegex
  - build-sys: extend configure check for kfreebsd
  - systemd: make sure the file system is writable before we write
    log data
* Mon Nov 15 2010 coolo@novell.com
- own parent directories for systemd files
* Sun Oct 31 2010 jengelh@medozas.de
- Use %%_smp_mflags
* Fri Sep 10 2010 coolo@novell.com
- fix build of -doc sub spec file
* Mon Sep  6 2010 kay.sievers@novell.com
- version 0.4.2
  - Ensure we only care for seat files ending in .seat (William Jon McCann)
  - Don't take bus name until ready
  - systemd hookup
  - add --since option to ck-history
  - Reduce number of threads on Linux
- install systemd service files
- disable silent build
* Tue May  4 2010 aj@suse.de
- Handle /var/run on tmpfs - Consolekit creates its runtime directory
  itself if needed.
* Tue May  4 2010 kay.sievers@novell.com
- add run-seat.d directories bnc#601236
* Thu Mar 11 2010 coolo@novell.com
- take some changes out of git to fix autologin in kdm (mainly
  fc2870a65f6b3ed3b71bcac69c5faf3a9c759c64)
* Mon Dec 14 2009 jengelh@medozas.de
- add baselibs.conf as a source
- enable parallel building
* Wed Dec  2 2009 kay.sievers@novell.com
- Update to 0.4.1
  * Starting with this release we will not do session.d/
    'session_active_changed' callouts anymore. (Lennart Poettering)
  * log the kernel release and boot arguments at start time (William Jon McCann)
  * show display in host field if the host isn't set (William Jon McCann)
  * print the uptime for the reboot items in the report (William Jon McCann)
  * Add seat.d/ callout directory and guarantee we dump the database before call
  * database: write the console database to disk before signalling via dbus
  * make CK database world readable (Lennart Poettering)
  * get rid of ck_seat_set_active_session() prototype
* Wed Jul 22 2009 kay.sievers@novell.com
- Update to 0.3.1:
  - port to polkit (Matthias Clasen)
  - D-Bus policy updates (Colin Walters, Martin Pitt, Vincent Untz, William Jon McCann)
  - better diagnostic information for unimplemented backends (Daniel Macks)
  - file monitoring fixes (James Westby)
  - get VT from X display if no controlling tty is available (Ray Strode)
  - add "nox11" option to PAM module (Martin Pitt)
  - parse log entries with no body correctly (William Jon McCann)
  - parse gecos field for real name (William Jon McCann)
  - leak fixes (James Westby, Steve Langasek)
* Wed Jul 15 2009 kay.sievers@novell.com
- fix misuse of libexecdir in file list for pkgconfig file
* Tue Apr 14 2009 hmacht@suse.de
- remove ConsoleKit-libexecdir.patch
- update ConsoleKit-fix-dbus-permissions.patch
- add ConsoleKit-fdo20471-GetSessions.patch to allow GetSessions on
  Manager interface (vuntz@novell.com)
- add ConsoleKit-allow-interfaces-required-by-gnome-session.patch to
  allow additional interfaces which are required by gnome-session
- Update to 0.3.0:
  - API changes to make the daemon conform to the published spec
  - don't allow reboot if PolicyKit and RBAC are disabled (William Jon McCann)
  - fix path in includes (William Jon McCann)
  - reorganize the docs a bit (William Jon McCann)
  - pull updated DTD and xsl from DeviceKit-disks (William Jon McCann)
  - fix distcheck (William Jon McCann)
  - still having problems using xinclude (William Jon McCann)
  - fix the includes (William Jon McCann)
  - add missing bits (William Jon McCann)
  - use spec files directly as introspection xml and try to generate docs on the fly (William Jon McCan
  - use object paths for seat added/removed signals per spec (William Jon McCann)
  - regenerate the docs and xml from the spec (William Jon McCann)
  - add GetLoginSessionId to exported interface (William Jon McCann)
  - fix use of unix-user as int (William Jon McCann)
  - use fortify source flag when building from git (William Jon McCann)
  - fix location of scripts again (William Jon McCann)
  - dist bzip by default (William Jon McCann)
  - fix up signal definition (William Jon McCann)
  - fix UnixUser to be uint (William Jon McCann)
  - use object paths instead of strings for signals (William Jon McCann)
  - cleanly shutdown event logging thread (William Jon McCann)
  - export login session id to the bus (William Jon McCann)
  - exit with the bus now that we're activated by the bus (William Jon McCann)
  - allow retaining authorizations for {stop,restart}-multiple-users (David Zeuthen)
  - make sure to add all override parameters (William Jon McCann)
  - fix the script to work with recent dbus-python api changes (William Jon McCann)
  - always try to detect parameters for session (William Jon McCann)
  - oops one more place (William Jon McCann)
  - install scripts into $(prefix)/lib instead of $libdir (William Jon McCann)
  - return PolicyKit results when not privileged for action (William Jon McCann)
  - fix typo (William Jon McCann)
  - initial login session id support (William Jon McCann)
  - display uid as unix-user to match api (William Jon McCann)
  - fix packaging of policy file (William Jon McCann)
  - rename policy file (William Jon McCann)
  - post release version bump (William Jon McCann)
* Fri Jan 23 2009 hmacht@suse.de
- fix D-Bus permissions (bnc#468371)
* Mon Dec  8 2008 hmacht@suse.de
- don't remove pam config on update (bnc#450962)
* Thu Oct 16 2008 ro@suse.de
- enhance baselibs.conf
- handle error case in postinstall more gracefully (#412794)
* Thu Oct  9 2008 hmacht@suse.de
- Remove %%ifarch calls, -32bit packages are selected through
  patterns. Force pam-config when YaST2 is running
  (bnc#433653,bnc#412794)
* Fri Sep 26 2008 hmacht@suse.de
- remove rc-script. ConsoleKit is activated on demand with D-Bus
  system activation (bnc#428228)
* Sun Aug 24 2008 ro@suse.de
- initscript: add $null to Required-Stop to fix build
* Mon Aug 11 2008 ro@suse.de
- fix build for ConsoleKit-doc
* Fri Jul 18 2008 hmacht@suse.de
- build with PolicyKit support (bnc#399476)
- update ConsoleKit-libexecdir.patch
* Tue May 13 2008 hmacht@suse.de
- also change libdir to prefix/lib in ck-session.c (bnc#386369)
* Fri Apr 18 2008 hmacht@suse.de
- update to version 0.2.10:
    always create the directories we need
    fix display of active vt when vt is disabled
    guard against writing null string to keyfile
    Also make criticals fatal when starting with --debug.
    reverse the sense of the dbus policy
    add a ck-launch-session tool
    don't set the session-type to the command name
    add tools to log restart and stop events
    fix typo in dbus policy file
    touch the history file to create it for people not using packages
    mkdir /var/log/ConsoleKit at install time
    set a global flag so that D-Bus does not change
    the SIGPIPE handler in the PAM module
    when a parsing error occurs don't return an empty event
    add a helper to write a system start record to the CK history
    add support for logging start/stop/restart
    allow session type filtering for all report formats
    add session-type filtering to ck-history
    try to activate x11-display-device not only display-device
    be a little smarter about how we compute the number of users
    fix policy action name
    history should log to /var/log not /var/run
- change %%%%_libexecdir to %%%%_prefix/lib
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Sat Apr  5 2008 coolo@suse.de
- leave out ConsoleKit-x11 in -doc.spec
* Tue Apr  1 2008 hmacht@suse.de
- create ConsoleKit-x11 containing the following files:
  /usr/lib/ck-get-x11-server-pid
  /usr/lib/ck-get-x11-display-device
  /usr/lib/ck-collect-session-info
* Sat Feb 16 2008 coolo@suse.de
- pwdutils split out login and we need it
* Tue Nov 27 2007 hmacht@suse.de
- add /etc/ConsoleKit/run-session.d and
  /usr/lib/ConsoleKit/run-session.d to files section (b.n.c 343246)
* Fri Nov  9 2007 hmacht@suse.de
- fix --localstatedir and add /var/run/ConsoleKit to files section
  (novell bug 340486)
* Wed Oct 17 2007 dkukawka@suse.de
- updated to git master (20071017):
  - add a way to synchronously run programs on session
    add/remove/activity_change
  - maintain a file with the dump of the local database
  - add event logging capability
  - Use unix-user instead of user so that PAM module works
  - FreeBSD support
  - Solaris support
  - More abstraction of system dependent stuff
  - Experimental support for seat & device configuration
  - Add new helper for getting tty from DISPLAY
  - a few fixes for getfd suggested by Lennart
* Mon Oct  1 2007 hmacht@suse.de
- remove 'PreReq: %%name-64bit' for ppc (novell bug 302148)
* Mon Sep  3 2007 hmacht@suse.de
- require pam-config >= 0.22 in PreReq (novell bug 306443)
* Sun Sep  2 2007 ro@suse.de
- no PreReq for doc package
* Wed Aug 29 2007 hmacht@suse.de
- PreReq either the 32bit or the 64bit pam plugin for pam-config to
  not fail (novell bug 302148)
* Fri Aug 17 2007 hmacht@suse.de
- run '/usr/sbin/pam-config --service login -a --ck_connector' in
  %%post section (novell bug 297559)
* Mon Aug  6 2007 hmacht@suse.de
- start ConsoleKit in runlevels 2 3 and 5 (insserv consolekit)
* Sat Aug  4 2007 aj@suse.de
- Reduce build requires.
* Sat Aug  4 2007 aj@suse.de
- Split of devel and doc packages.
* Fri Aug  3 2007 hmacht@suse.de
- remove dbus-1-devel from "Requires:"
* Wed Apr 25 2007 hmacht@suse.de
- update to version 0.2.1:
  - disable static libs
  - use inotify to detect activity on tty when possible
  - add support for CKCON_X11_DISPLAY_DEVICE environment variable
  - also add ability to toggle debugging when SIGUSR1 is received
  - several autoconf fixes and cleanups
  - typo fixes in documentation
  - misc fixes
* Mon Apr  2 2007 hmacht@suse.de
- initial checkin
